@@ -1,13 +1,15 @@
-use rustc_hash::FxHashMap;
 use swc_atoms::{js_word, JsWord};
-use swc_common::{collections::AHashSet, sync::Lrc};
+use swc_common::{
+    collections::{AHashMap, AHashSet},
+    sync::Lrc,
+};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{collect_decls, Id};
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
 
 pub fn inline_globals(
-    envs: Lrc<FxHashMap<JsWord, Expr>>,
-    globals: Lrc<FxHashMap<JsWord, Expr>>,
+    envs: Lrc<AHashMap<JsWord, Expr>>,
+    globals: Lrc<AHashMap<JsWord, Expr>>,
 ) -> impl Fold + VisitMut {
     as_folder(InlineGlobals {
         envs,
@@ -17,8 +19,8 @@ pub fn inline_globals(
 }
 
 struct InlineGlobals {
-    envs: Lrc<FxHashMap<JsWord, Expr>>,
-    globals: Lrc<FxHashMap<JsWord, Expr>>,
+    envs: Lrc<AHashMap<JsWord, Expr>>,
+    globals: Lrc<AHashMap<JsWord, Expr>>,
 
     bindings: AHashSet<Id>,
 }
@@ -114,8 +116,8 @@ mod tests {
         tester: &mut Tester<'_>,
         values: &[(&str, &str)],
         is_env: bool,
-    ) -> FxHashMap<JsWord, Expr> {
-        let mut m = FxHashMap::default();
+    ) -> AHashMap<JsWord, Expr> {
+        let mut m = AHashMap::default();
 
         for (k, v) in values {
             let v = if is_env {
@@ -146,11 +148,11 @@ mod tests {
         m
     }
 
-    fn envs(tester: &mut Tester<'_>, values: &[(&str, &str)]) -> Lrc<FxHashMap<JsWord, Expr>> {
+    fn envs(tester: &mut Tester<'_>, values: &[(&str, &str)]) -> Lrc<AHashMap<JsWord, Expr>> {
         Lrc::new(mk_map(tester, values, true))
     }
 
-    fn globals(tester: &mut Tester<'_>, values: &[(&str, &str)]) -> Lrc<FxHashMap<JsWord, Expr>> {
+    fn globals(tester: &mut Tester<'_>, values: &[(&str, &str)]) -> Lrc<AHashMap<JsWord, Expr>> {
         Lrc::new(mk_map(tester, values, false))
     }
 
